Tutorials
=========

These documents should serve as a way to discover icclim and it's capabilities.
To see how icclim can solve specific issues see :ref:`how_to`.

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    installation
